@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# Application Name - Health Check V0.5.0-4
+# Application Name - Health Check V0.5.0-5
 # Date 17 February 2010
 # Author - Greg Roberts (Noobmonkey @ Maemo Talk)
 # Contact - Me@Greg-roberts.com
@@ -174,7 +174,7 @@ class Ui_MainWindow(object):
 
         # Label to show the maemo firmware version Information
         self.lbl_Maemo_Ver_Info = QtGui.QLabel(self.tab)
-        self.lbl_Maemo_Ver_Info.setGeometry(QtCore.QRect(160, 60, 331, 21))
+        self.lbl_Maemo_Ver_Info.setGeometry(QtCore.QRect(160, 60, 600, 21))
         self.lbl_Maemo_Ver_Info.setFont(font)
         self.lbl_Maemo_Ver_Info.setObjectName("lbl_Maemo_Ver_Info")
 
@@ -359,7 +359,7 @@ class Ui_MainWindow(object):
         # box of some sort
         self.textBrowser = QtGui.QTextBrowser(self.tab_5)
         self.textBrowser.setGeometry(QtCore.QRect(0, 10, 781, 301))
-        self.textBrowser.setText (" Health Check V 0.5.0-4 \n Greg Roberts (Maemo.org - Noobmonkey) \n me@greg-roberts.com \n \n For Bugs and Feature requests: \n http://talk.maemo.org/showthread.php?p=541457")
+        self.textBrowser.setText (" Health Check V 0.5.0-5 \n Greg Roberts (Maemo.org - Noobmonkey) \n me@greg-roberts.com \n \n For Bugs and Feature requests: \n http://talk.maemo.org/showthread.php?p=541457")
         # Make the font small!!!
         font = QtGui.QFont()
         font.setPointSize(20)
@@ -432,7 +432,49 @@ class Ui_MainWindow(object):
         # This one reads fremantle version number (Firmware)
         g = os.popen('dpkg -l "mp-fremantle-*"').read()
         g = g.strip()[-15:]
-        self.lbl_Maemo_Ver_Info.setText(g.strip())
+        g = str(g)
+        g.strip()
+        g.lstrip()
+        g.rstrip()
+
+        if g.strip() == "3.2010.02-8":
+            self.lbl_Maemo_Ver_Info.setText(g.strip() + " - Pr 1.1.1")
+        elif g.strip() == "2.2009.51-1":
+            self.lbl_Maemo_Ver_Info.setText(g.strip() + " - Pr 1.1")
+        elif g.strip() == "1.2009.44-1":
+            self.lbl_Maemo_Ver_Info.setText(g.strip() + " - Pr 1.01")
+        elif g.strip() == "1.2009.42-11":
+            self.lbl_Maemo_Ver_Info.setText(g.strip() + " - Pr 1 - Initial public release ")
+        elif g.strip() == "1.2009.42-11.002":
+            self.lbl_Maemo_Ver_Info.setText(g.strip() + " - Pr 1 USA Variant ")
+        elif g.strip() == "1.2009.42-11.003":
+            self.lbl_Maemo_Ver_Info.setText(g.strip() + " - Pr 1 Mid-East/N-Africa Variant")
+        elif g.strip() == "1.2009.42-11.203":
+            self.lbl_Maemo_Ver_Info.setText(g.strip() + " - Pr 1 UK Generic Version")
+        elif g.strip() == "1.2009.42-11.203.0":
+            self.lbl_Maemo_Ver_Info.setText(g.strip() + " - Pr 1 UK Generic Version")
+        elif g.strip() == "1.2009.42-11.203.1":
+            self.lbl_Maemo_Ver_Info.setText(g.strip() + " - Pr 1 UK Generic Version")
+        elif g.strip() == "1.2009.42-11.203.2":
+            self.lbl_Maemo_Ver_Info.setText(g.strip() + " - Pr 1 UK Generic Version")
+        elif g.strip() == "1.2009.42-11.205":
+            self.lbl_Maemo_Ver_Info.setText(g.strip() + " - Pr 1 UK Vodafone Version")
+        elif g.strip() == "1.2009.42-11.205.0":
+            self.lbl_Maemo_Ver_Info.setText(g.strip() + " - Pr 1 UK Vodafone Version")
+        elif g.strip() == "1.2009.42-11.205.1":
+            self.lbl_Maemo_Ver_Info.setText(g.strip() + " - Pr 1 UK Vodafone Version")
+        elif g.strip() == "1.2009.42-11.205.2":
+            self.lbl_Maemo_Ver_Info.setText(g.strip() + " - Pr 1 UK Vodafone Version")
+        elif g.strip() == "1.2009.41-1":
+            self.lbl_Maemo_Ver_Info.setText(g.strip() + " - Early Release Vanilla Variant")
+        else:
+           self.lbl_Maemo_Ver_Info.setText(g + " - Varient unknown -")
+           print "Firmware variants"
+           print g
+           print str(g)
+           print g.strip()
+           print g.find("3.2010.02-8")
+
 
 # Funtion - update CPU Information
     def updateCPU(self):
@@ -457,11 +499,11 @@ class Ui_MainWindow(object):
         # Do some string functions to find/remove messy parts of the battery pulled text.
         # Please excuse the poorly labeled variables here!
         C_a = str(bg)[:-15]
-        print C_a
+        
         C_b = str(C_a)[-4:]
-        print C_b
+        
         barxval = str.strip(C_b)
-        print barxval
+        
         self.lbl_Battery_Bar.setRange(0,100)
         self.lbl_Battery_Bar.setProperty("value", barxval)
 
@@ -537,7 +579,7 @@ class Ui_MainWindow(object):
         
     # This is the start of the QT Designer translation function - not using the translation function, but left it in, to show it is part of the class   
     def retranslateUi(self, MainWindow):
-        MainWindow.setWindowTitle(QtGui.QApplication.translate("MainWindow", "Health Check 0.5.0-4", None, QtGui.QApplication.UnicodeUTF8))
+        MainWindow.setWindowTitle(QtGui.QApplication.translate("MainWindow", "Health Check 0.5.0-5", None, QtGui.QApplication.UnicodeUTF8))
         self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab), QtGui.QApplication.translate("MainWindow", "System", None, QtGui.QApplication.UnicodeUTF8))
         self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_2), QtGui.QApplication.translate("MainWindow", "Comms", None, QtGui.QApplication.UnicodeUTF8))
         self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_3), QtGui.QApplication.translate("MainWindow", "Camera", None, QtGui.QApplication.UnicodeUTF8))
